@@ -1,10 +1,10 @@
 """Ready to use and customizable Authentications and Oauth2 management for FastAPI"""
 
-__version__ = "0.0.9"
+__version__ = "0.1.0"
 
 __license__ = "MIT"
 
-__author__ = "Yezz123"
+__author__ = "Yasser Tahiri"
 
 __author_email__ = "yasserth19@gmail.com"
 
